@@ -34,19 +34,8 @@
 #include <gphoto2/gphoto2-setting.h>
 #include "ax203.h"
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (GETTEXT_PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
+#include "libgphoto2/i18n.h"
+
 
 static const struct ax203_devinfo ax203_devinfo[] = {
 	{ 0x1908, 0x1315, AX203_FIRMWARE_3_3_x },
