@@ -44,7 +44,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <_stdint.h>
+#include <stdint.h>
 #include <errno.h>
 
 #include "tinyjpeg.h"
