@@ -23,13 +23,10 @@
 #include <fcntl.h>
 #include <string.h>
 #include <math.h>
-#ifdef OS2
-#include <db.h>
-#endif
 
 #include <gphoto2/gphoto2.h>
 #include <gphoto2/gphoto2-port.h>
-#include <gamma.h>
+#include <libgphoto2/gamma.h>
 #include "digigr8.h"
 
 #define GP_MODULE "digigr8"
@@ -243,7 +240,7 @@ digi_decompress (unsigned char *out_data, unsigned char *data,
 }
 
 /* Brightness correction routine adapted from
- * camlibs/polaroid/jd350e.c, copyright  2001 Michael Trawny
+ * camlibs/polaroid/jd350e.c, copyright © 2001 Michael Trawny
  * <trawny99@users.sourceforge.net>
  */
 
