@@ -1,52 +1,44 @@
 /* blink2.c
  *
- * Copyright  2004 Olivier Fauchon <olivier@aixmarseille.com>
+ * Copyright 2004 Olivier Fauchon <olivier@aixmarseille.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2 of the License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful, 
- * but WITHOUT ANY WARRANTY; without even the implied warranty of 
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details. 
+ * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  *
  */
 
-#define _POSIX_C_SOURCE 199309L
-
 #include "config.h"
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <unistd.h>
 
 #include <gphoto2/gphoto2-library.h>
 #include <gphoto2/gphoto2-port-log.h>
 #include <gphoto2/gphoto2-result.h>
-#include "gphoto2-endian.h"
+#include "libgphoto2/gphoto2-endian.h"
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (GETTEXT_PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define _(String) (String)
-#  define N_(String) (String)
+#include "libgphoto2/i18n.h"
+
+
+#ifdef FUZZING_BUILD_MODE_UNSAFE_FOR_PRODUCTION
+#define sleep(x)
+#define usleep(x)
 #endif
 
+
 #define ENIGMA13_BLK_FLASH_ALIGN 0x2000
 #define ENIGMA13_BLK_CARD_ALIGN 0x4000
 #define ENIGMA13_USB_TIMEOUT_MS 5000
@@ -61,7 +53,7 @@
 
 
 /* the table of content of the camera
-   it's filled in enigma_get_toc, and used in enigma_download_img */    
+   it's filled in enigma_get_toc, and used in enigma_download_img */
 static char* enigma13_static_toc=NULL;
 
 
@@ -70,8 +62,8 @@ static char* enigma13_static_toc=NULL;
 static int enigma13_about (Camera *camera, CameraText *about, GPContext *context)
 {
         strcpy (about->text, _("Download program for Digital Dream Enigma 1.3. "
-                "by <olivier@aixmarseille.com>, and adapted from spca50x driver."
-                "Thanks you, spca50x team, it was easy to port your driver on this cam! "));
+                "by <olivier@aixmarseille.com>, and adapted from spca50x driver. "
+                "Thank you, spca50x team, it was easy to port your driver on this cam! "));
         return (GP_OK);
 }
 
@@ -91,7 +83,7 @@ static int enigma13_detect_storage_type (Camera *camera)
         for (i=0;i<3;i++)
         {
                 CHECK (gp_port_usb_msg_read (camera->port, 0x28, 0x0000,
-                                        i, &buf[i], 0x01));           
+                                        i, &buf[i], 0x01));
         }
         gp_log(GP_LOG_DEBUG, "enigma13","Camera storage information sdram: 0x%x flash 0x%x card: 0x%x\n"
                         , buf[0], buf[1], buf[2]);
@@ -107,7 +99,7 @@ static int enigma13_detect_storage_type (Camera *camera)
  * This function deletes all the images
  * supported (sdram, flash, card)
  *
- * Status: not verified 
+ * Status: not verified
  */
 static int
 enigma13_flash_delete_all(CameraFilesystem *fs, const char *folder, void *data,
@@ -117,7 +109,7 @@ enigma13_flash_delete_all(CameraFilesystem *fs, const char *folder, void *data,
    gp_log(GP_LOG_DEBUG, "enigma13","Delete all files");
    cam = data;
    CHECK (gp_port_usb_msg_write (cam->port, 0x52, 0x0, 0x0, NULL, 0x0) );
-   return GP_OK;                             
+   return GP_OK;
 }
 
 
@@ -126,8 +118,8 @@ enigma13_flash_delete_all(CameraFilesystem *fs, const char *folder, void *data,
 /*
  * This function waits camera is ready
  *
- * Status: Not sure what it realy does, but the camera replies
- * Can this be some kind of ping for keepalive, or realy a ready status ?
+ * Status: Not sure what it really does, but the camera replies
+ * Can this be some kind of ping for keepalive, or really a ready status ?
  */
 static int enigma13_wait_for_ready(Camera *camera)
 {
@@ -149,7 +141,7 @@ static int enigma13_wait_for_ready(Camera *camera)
 #if 0
 /*
  * Get the number of images in cam
- * 
+ *
  * Status: Should work, but not used as enigma13_get_TOC does all.
  *
  */
@@ -160,7 +152,7 @@ static int enigma13_get_filecount (Camera *camera, int *filecount)
         CHECK (gp_port_usb_msg_read (camera->port,
                              0x54, 0x0000, 0x0000,
                              (char*)&response, 0x02));
-        LE16TOH (response);
+        le16toh (response);
         *filecount = response;
         return GP_OK;
 }
@@ -170,7 +162,7 @@ static int enigma13_get_filecount (Camera *camera, int *filecount)
 
 
 /*
- * Get the table of contents (directory) from the cam 
+ * Get the table of contents (directory) from the cam
  *
  * Verified: Yes
  */
@@ -186,7 +178,7 @@ static int enigma13_get_toc(Camera *camera, int *filecount, char** toc)
         CHECK (gp_port_usb_msg_read (camera->port,
                              0x54, 0x0000, 0x0000,
                              (char*)&response, 0x02));
-        LE16TOH (response);
+        le16toh (response);
         *filecount = response;
 
         /* Calc toc size */
@@ -201,7 +193,7 @@ static int enigma13_get_toc(Camera *camera, int *filecount, char** toc)
                            response, 0x0001,
                           NULL, 0x0000));
         /* Wait until cam is ready to send the T.O.C */
-	GP_SYSTEM_SLEEP(ENIGMA13_WAIT_TOC_DELAY_MS);
+	usleep(ENIGMA13_WAIT_TOC_DELAY_MS * 1000);
 
         CHECK (gp_port_usb_msg_read (camera->port, 0x21,
                            0x0000, 0x0000,
@@ -233,14 +225,14 @@ static int enigma13_get_toc(Camera *camera, int *filecount, char** toc)
  * int    index   : image index ( in gphoto point of view) -1 for real index
  * char*  toc     : pointer to toc
  * char** img_buf : returned image data
- * int* img_size      : returned image data size  
+ * int* img_size      : returned image data size
  *
  */
 static int enigma13_download_img(Camera *camera, char *toc, int index, char **img_data, int *img_size)
 {
 	uint8_t *p;
 	uint32_t file_size = 0, aligned_size = 0;
-	char* buf=NULL; 
+	char* buf=NULL;
 	int align=0;
 	char  retbuf[2];
 
@@ -248,7 +240,7 @@ static int enigma13_download_img(Camera *camera, char *toc, int index, char **im
 
 	/* Offset for image informations .
 	Each image has 16 bytes for name and 16 for size, and others*/
-	p = toc + (index*2)*32;
+	p = (uint8_t *)toc + (index*2)*32;
 
 	/* real size from toc*/
 	aligned_size = file_size =
@@ -261,10 +253,10 @@ static int enigma13_download_img(Camera *camera, char *toc, int index, char **im
 		retbuf, 0x01));
 	if (retbuf[0]==0x20){
 		align=ENIGMA13_BLK_CARD_ALIGN;
-		gp_log(GP_LOG_DEBUG, "enigma13"," Image from card, alignement is set to %d bytes ",align);
+		gp_log(GP_LOG_DEBUG, "enigma13"," Image from card, alignment is set to %d bytes ",align);
 	} else if (retbuf[0]==0x10){
 		align=ENIGMA13_BLK_FLASH_ALIGN;
-		gp_log(GP_LOG_DEBUG, "enigma13"," Image from flash, alignement is set to %d bytes",align);
+		gp_log(GP_LOG_DEBUG, "enigma13"," Image from flash, alignment is set to %d bytes",align);
 	} else {
 		return GP_ERROR;
 	}
@@ -278,7 +270,7 @@ static int enigma13_download_img(Camera *camera, char *toc, int index, char **im
 
 	CHECK_AND_FREE (gp_port_usb_msg_write (camera->port,
 	0x54, index+1, 2, NULL, 0x00), buf);
-	GP_SYSTEM_SLEEP(ENIGMA13_WAIT_IMAGE_READY_MS);
+	usleep(ENIGMA13_WAIT_IMAGE_READY_MS * 1000);
 
 	CHECK_AND_FREE (gp_port_usb_msg_read (camera->port, 0x21,
 		0x0000, 0x0000,
@@ -334,7 +326,7 @@ static int file_list_func (CameraFilesystem *fs, const char *folder, CameraList
 
 
 /*
- * File operations 
+ * File operations
  */
 static int
 get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
@@ -358,7 +350,7 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 
                 CHECK(enigma13_download_img(camera, enigma13_static_toc, image_no, &img_data, &img_size));
                 result = gp_file_append( file, img_data, img_size);
- 
+
 		break;
 	}
 	default:
@@ -371,7 +363,7 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 }
 
 int
-camera_abilities (CameraAbilitiesList *list) 
+camera_abilities (CameraAbilitiesList *list)
 {
 	CameraAbilities a;
 
@@ -390,7 +382,7 @@ camera_abilities (CameraAbilitiesList *list)
 }
 
 int
-camera_id (CameraText *id) 
+camera_id (CameraText *id)
 {
 	strcpy(id->text, "Digital Dream Enigma 1.3");
 	return (GP_OK);
@@ -403,7 +395,7 @@ static CameraFilesystemFuncs fsfuncs = {
 };
 
 int
-camera_init (Camera *camera, GPContext *context) 
+camera_init (Camera *camera, GPContext *context)
 {
 	GPPortSettings settings;
 
