@@ -39,21 +39,10 @@
 
 #include <gphoto2/gphoto2-library.h>
 
+#include "libgphoto2/i18n.h"
+
 #include "library.h"
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (GETTEXT_PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
 
 /*
  * FIXME: Use properly sized integer types. The dc3200 code used lots
