@@ -36,15 +36,22 @@
 #include <libxml/xmlreader.h>
 
 
-#include <sys/socket.h>
+#ifdef WIN32
+# include <winsock2.h>
+# include <ws2tcpip.h>
+#else
+# include <sys/socket.h>
+# include <netinet/in.h>
+# include <arpa/inet.h>
+#endif
 #include <stdlib.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
 
 
 #include <gphoto2/gphoto2-library.h>
 #include <gphoto2/gphoto2-result.h>
 
+#include "libgphoto2/i18n.h"
+
 
 #define GP_MODULE "lumix"
 
@@ -59,31 +66,6 @@
 }
 
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-/**
-* This define is the string translation macro used in
-* libgphoto2. It will resolve to a dcgettext() function call and
-* does both the translation itself and also marks up the string
-* for the collector (xgettext).
-*/
-#  define _(String) dgettext (GETTEXT_PACKAGE, String)
-#  ifdef gettext_noop
-/**
-* This is the noop translation macro, which does not translate the
-* string, but marks it up for the extraction of translatable strings.
-*/
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
-
-
 char* CDS_Control  = ":60606/Server0/CDS_control";
 int ReadoutMode = 2; // this should be picked up from the settings.... 0-> JPG; 1->RAW; 2 -> Thumbnails
 char* cameraShutterSpeed = "B"; // //placeholder to store the value of the shutterspeed set in camera; "B" is for bulb.
