@@ -25,23 +25,11 @@
 
 #include <stdio.h>
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  ifdef gettext_noop
-#    define _(String) dgettext (GETTEXT_PACKAGE, String)
-#    define N_(String) gettext_noop (String)
-#  else
-#    define _(String) (String)
-#    define N_(String) (String)
-#  endif
-#else
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
+#include "libgphoto2/i18n.h"
 
 #include "dimagev.h"
 
+
 #define GP_MODULE "dimagev"
 
 int camera_id (CameraText *id)
