@@ -27,23 +27,12 @@
 #endif
 #include <string.h>
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (GETTEXT_PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
+#include "libgphoto2/i18n.h"
 
 #include "dc.h"
 #include "dc1000.h"
 
+
 #ifndef __FILE__
 #  define __FILE__ "dc1000.c"
 #endif
