@@ -22,24 +22,12 @@
 #include <stdio.h>
 #include <string.h>
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (GETTEXT_PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
-
-#include "gphoto2-endian.h"
+#include "libgphoto2/i18n.h"
+#include "libgphoto2/gphoto2-endian.h"
 #include <gphoto2/gphoto2-port-log.h>
 #include <gphoto2/gphoto2-library.h>
 
+
 #ifndef __FILE__
 #  define __FILE__ "l859.c"
 #endif
