@@ -19,8 +19,8 @@
 /*                                                              */
 /* You should have received a copy of the GNU Library General   */
 /* Public License along with this library; if not, write to the */
-/* Free Software Foundation, Inc., 59 Temple Place - Suite 330, */
-/* Boston, MA 02111-1307, USA.                                  */
+/* Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,*/
+/* Boston, MA  02110-1301  USA					*/
 /****************************************************************/
 
 #include <config.h>
@@ -104,7 +104,9 @@ file_list_func (CameraFilesystem *fs, const char *folder,
 		CameraList *list, void *data, GPContext *context)
 {
 	Camera *camera = data;
-	unsigned int i, filecount, id, size, type;
+	int i;
+	unsigned int id, size, type;
+	int filecount;
 	CameraFile *file;
 	CameraFileInfo info;
 	unsigned char *buffer = NULL;
@@ -115,11 +117,11 @@ file_list_func (CameraFilesystem *fs, const char *folder,
 
 	id = gp_context_progress_start (context, filecount,
 			_("Getting file list..."));
-	
+
 	for (i = 0; i < filecount; i++) {
 		/* Get information */
 		gp_file_new (&file);
-	
+
 		ret = pccam300_get_file (camera->port, context, i,
 		                          &buffer, &size, &type);
 		if (ret < GP_OK) {
@@ -151,13 +153,13 @@ file_list_func (CameraFilesystem *fs, const char *folder,
 		}
 
 		if (file)
-			gp_file_set_data_and_size (file, buffer, size);
+			gp_file_set_data_and_size (file, (char *)buffer, size);
 		else
 			free (buffer);
-		
+
 		/*
 		 * Append directly to the filesystem instead of to the list,
-		 * because we have additional information. 
+		 * because we have additional information.
 		 * */
 		gp_filesystem_append (camera->fs, folder, fn, context);
 		gp_filesystem_set_info_noop (camera->fs, folder, fn, info, context);
@@ -181,7 +183,8 @@ get_file_func (CameraFilesystem *fs, const char *folder,
 {
 	Camera *camera = user_data;
 	unsigned char *data = NULL;
-	unsigned int size, index, mimetype;
+	unsigned int size, mimetype;
+	int index;
 
 	size = 0;
 	index = gp_filesystem_number (fs, folder, filename, context);
@@ -196,7 +199,7 @@ get_file_func (CameraFilesystem *fs, const char *folder,
 		default:
 			return GP_ERROR_NOT_SUPPORTED;
 	}
-	return gp_file_set_data_and_size (file, data, size);
+	return gp_file_set_data_and_size (file, (char *)data, size);
 }
 
 static int
