@@ -154,6 +154,12 @@ camera_abilities (CameraAbilitiesList *list)
         strcpy (a.model, "Pentax:K70");
 	a.usb_vendor		= 0x25fb;
         a.usb_product           = 0x017c;
+        if (GP_OK != (ret = gp_abilities_list_append (list, a)))
+                return ret;
+	/* fifu7fi@gmail.com */
+        strcpy (a.model, "Pentax:KP");
+	a.usb_vendor		= 0x25fb;
+        a.usb_product           = 0x017e;
         if (GP_OK != (ret = gp_abilities_list_append (list, a)))
                 return ret;
 	return GP_OK;
@@ -409,6 +415,8 @@ camera_capture (Camera *camera, CameraCaptureType type, CameraFilePath *path,
 		}
 		/* We have now handed over the file, disclaim responsibility by unref. */
 		gp_file_unref (file);
+
+		memset (&info, 0, sizeof (info));
 		/* we also get the fs info for free, so just set it */
 		info.file.fields = GP_FILE_INFO_TYPE |
 				GP_FILE_INFO_SIZE | GP_FILE_INFO_MTIME;
@@ -568,6 +576,8 @@ camera_wait_for_event (Camera *camera, int timeout,
 			}
 			/* We have now handed over the file, disclaim responsibility by unref. */
 			gp_file_unref (file);
+
+			memset (&info, 0, sizeof (info));
 			/* we also get the fs info for free, so just set it */
 			info.file.fields = GP_FILE_INFO_TYPE |
 					GP_FILE_INFO_SIZE | GP_FILE_INFO_MTIME;
