@@ -26,11 +26,14 @@
 
 #include <gphoto2/gphoto2-library.h>
 #include <gphoto2/gphoto2-port-log.h>
-#include <bayer.h>
+
+#include <libgphoto2/bayer.h>
+#include "libgphoto2/i18n.h"
 
 #include "jd350e.h"
 #include "dlink350f.h"
 
+
 #define GP_MODULE "pdc640"
 
 #define PDC640_PING  "\x01"
@@ -40,26 +43,6 @@
 
 #define CHECK_RESULT(result) {int __r = (result); if (__r < 0) return (__r);}
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (GETTEXT_PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define textdomain(String) (String)
-#  define gettext(String) (String)
-#  define dgettext(Domain,Message) (Message)
-#  define dcgettext(Domain,Message,Type) (Message)
-#  define bindtextdomain(Domain,Directory) (Domain)
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
-
-
 typedef enum{
 	pdc640,
 	jd350e,
