@@ -68,31 +68,14 @@
 #include <gphoto2/gphoto2-port-log.h>
 #include <gphoto2/gphoto2-setting.h>
 
+#include "libgphoto2/i18n.h"
+
 #include "ptp.h"
 #include "ptp-private.h"
 
 #define PTPIP_VERSION_MAJOR 0x0001
 #define PTPIP_VERSION_MINOR 0x0000
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (GETTEXT_PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define textdomain(String) (String)
-#  define gettext(String) (String)
-#  define dgettext(Domain,Message) (Message)
-#  define dcgettext(Domain,Message,Type) (Message)
-#  define bindtextdomain(Domain,Directory) (Domain)
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
-
 #include "ptp.h"
 #include "ptp-bugs.h"
 
@@ -158,10 +141,14 @@ ptp_fujiptpip_sendreq (PTPParams* params, PTPContainer* req, int dataphase)
 		break;
 	}
 	GP_LOG_DATA ( (char*)request, len, "ptpip/oprequest data:");
-	ret = write (params->cmdfd, request, len);
+	ret = ptpip_write_with_timeout (params->cmdfd, request, len, PTPIP_DEFAULT_TIMEOUT_S, PTPIP_DEFAULT_TIMEOUT_MS);
 	free (request);
-	if (ret == -1)
-		perror ("sendreq/write to cmdfd");
+	if (ret == PTPSOCK_ERR) {
+		ptpip_perror ("sendreq/write to cmdfd");
+		if (ptpip_get_socket_error() == ETIMEDOUT)
+			return PTP_ERROR_TIMEOUT;
+		return PTP_ERROR_IO;
+	}
 	if (ret != len) {
 		GP_LOG_E ("ptp_fujiptpip_sendreq() len =%d but ret=%d", len, ret);
 		return PTP_RC_OK;
@@ -181,15 +168,17 @@ ptp_fujiptpip_generic_read (PTPParams *params, int fd, PTPIPHeader *hdr, unsigne
 		hdrlen = len = sizeof(uint32_t);
 
 	while (curread < len) {
-		ret = read (fd, xhdr + curread, len - curread);
-		if (ret == -1) {
-			perror ("read PTPIPHeader");
-			return PTP_RC_GeneralError;
+		ret = ptpip_read_with_timeout (fd, xhdr + curread, len - curread, PTPIP_DEFAULT_TIMEOUT_S, PTPIP_DEFAULT_TIMEOUT_MS);
+		if (ret == PTPSOCK_ERR) {
+			ptpip_perror ("read fujiptpip generic");
+			if (ptpip_get_socket_error() == ETIMEDOUT)
+				return PTP_ERROR_TIMEOUT;
+			return PTP_ERROR_IO;
 		}
 		GP_LOG_DATA ((char*)xhdr+curread, ret, "ptpip/generic_read header:");
 		curread += ret;
 		if (ret == 0) {
-			GP_LOG_E ("End of stream after reading %d bytes of ptpipheader", ret);
+			GP_LOG_E ("End of stream after reading %d bytes of ptpipheader", curread);
 			return PTP_RC_GeneralError;
 		}
 	}
@@ -205,11 +194,13 @@ ptp_fujiptpip_generic_read (PTPParams *params, int fd, PTPIPHeader *hdr, unsigne
 	}
 	curread = 0;
 	while (curread < len) {
-		ret = read (fd, (*data)+curread, len-curread);
-		if (ret == -1) {
-			GP_LOG_E ("error %d in reading PTPIP data", errno);
+		ret = ptpip_read_with_timeout (fd, (*data)+curread, len-curread, PTPIP_DEFAULT_TIMEOUT_S, PTPIP_DEFAULT_TIMEOUT_MS);
+		if (ret == PTPSOCK_ERR) {
+			GP_LOG_E ("error %d in reading PTPIP data", ptpip_get_socket_error());
 			free (*data);*data = NULL;
-			return PTP_RC_GeneralError;
+			if (ptpip_get_socket_error() == ETIMEDOUT)
+				return PTP_ERROR_TIMEOUT;
+			return PTP_ERROR_IO;
 		} else {
 			GP_LOG_DATA ((char*)((*data)+curread), ret, "ptpip/generic_read data:");
 		}
@@ -277,9 +268,13 @@ ptp_fujiptpip_senddata (PTPParams* params, PTPContainer* ptp,
 	htod16a(&request[fujiptpip_data_code],ptp->Code);
 	htod32a(&request[fujiptpip_data_transid],ptp->Transaction_ID);
 	GP_LOG_DATA ((char*)request, sizeof(request), "ptpip/senddata header:");
-	ret = write (params->cmdfd, request, sizeof(request));
-	if (ret == -1)
-		perror ("sendreq/write to cmdfd");
+	ret = ptpip_write_with_timeout (params->cmdfd, request, sizeof(request), PTPIP_DEFAULT_TIMEOUT_S, PTPIP_DEFAULT_TIMEOUT_MS);
+	if (ret == PTPSOCK_ERR) {
+		ptpip_perror ("sendreq/write to cmdfd");
+		if (ptpip_get_socket_error() == ETIMEDOUT)
+			return PTP_ERROR_TIMEOUT;
+		return PTP_ERROR_IO;
+	}
 	if (ret != sizeof(request)) {
 		GP_LOG_E ("ptp_fujiptpip_senddata() len=%d but ret=%d", (int)sizeof(request), ret);
 		return PTP_RC_GeneralError;
@@ -298,7 +293,7 @@ ptp_fujiptpip_senddata (PTPParams* params, PTPContainer* ptp,
 		}
 		ret = handler->getfunc (params, handler->priv, towrite, xdata, &xtowrite);
 		if (ret == -1) {
-			perror ("getfunc in senddata failed");
+			ptpip_perror ("getfunc in senddata failed");
 			free (xdata);
 			return PTP_RC_GeneralError;
 		}
@@ -307,10 +302,12 @@ ptp_fujiptpip_senddata (PTPParams* params, PTPContainer* ptp,
 		written = 0;
 		while (written < towrite2) {
 			ret = write (params->cmdfd, xdata+written, towrite2-written);
-			if (ret == -1) {
-				perror ("write in senddata failed");
+			if (ret == PTPSOCK_ERR) {
+				ptpip_perror ("write in senddata failed");
 				free (xdata);
-				return PTP_RC_GeneralError;
+				if (ptpip_get_socket_error() == ETIMEDOUT)
+					return PTP_ERROR_TIMEOUT;
+				return PTP_ERROR_IO;
 			}
 			written += ret;
 		}
@@ -571,6 +568,7 @@ ptp_fujiptpip_getresp (PTPParams* params, PTPContainer* resp)
 	return PTP_RC_OK;
 }
 
+#define fujiptpip_initcmd_packet_size		82
 #define fujiptpip_initcmd_protocolversion	8
 #define fujiptpip_initcmd_guid			12
 #define fujiptpip_initcmd_name			28
@@ -580,7 +578,7 @@ ptp_fujiptpip_init_command_request (PTPParams* params)
 {
 	char		hostname[100];
 	unsigned char*	cmdrequest;
-	unsigned int	i;
+	unsigned int	i, namelen;
 	int 		len, ret;
 	unsigned char	guid[16];
 
@@ -593,16 +591,20 @@ ptp_fujiptpip_init_command_request (PTPParams* params)
 	if (!GetComputerNameA(hostname, &hostname_size))
 		return PTP_RC_GeneralError;
 #endif
-	len = fujiptpip_initcmd_name + (strlen(hostname)+1)*2;
+	len = fujiptpip_initcmd_packet_size; // Fuji X-Acquire always sends packets of fixed length 82. At least the X-T4 just closes the socket when sending packets of other lengths.
+	namelen = (len - fujiptpip_initcmd_name - 1) / 2; // Length in UCS-2 characters, excluding the 0 byte at the end.
+	if(strlen(hostname) < namelen)
+		namelen = strlen(hostname);
 
 	cmdrequest = malloc(len);
+	memset(cmdrequest, 0, len);
 	htod32a(&cmdrequest[fujiptpip_type],PTPIP_INIT_COMMAND_REQUEST);
 	htod32a(&cmdrequest[fujiptpip_len],len);
 
 	htod32a(&cmdrequest[fujiptpip_initcmd_protocolversion], 0x8f53e4f2);	/* magic number */
 
 	memcpy(&cmdrequest[fujiptpip_initcmd_guid], guid, 16);
-	for (i=0;i<strlen(hostname)+1;i++) {
+	for (i=0;i<namelen;i++) {
 		/* -> ucs-2 in little endian */
 		cmdrequest[fujiptpip_initcmd_name+i*2] = hostname[i];
 		cmdrequest[fujiptpip_initcmd_name+i*2+1] = 0;
@@ -615,13 +617,15 @@ ptp_fujiptpip_init_command_request (PTPParams* params)
 
 
 	GP_LOG_DATA ((char*)cmdrequest, len, "ptpip/init_cmd data:");
-	ret = PTPSOCK_WRITE (params->cmdfd, cmdrequest, len);
+	ret = ptpip_write_with_timeout (params->cmdfd, cmdrequest, len, PTPIP_DEFAULT_TIMEOUT_S, PTPIP_DEFAULT_TIMEOUT_MS);
 	free (cmdrequest);
 	if (ret == PTPSOCK_ERR) {
-		perror("write init cmd request");
-		return PTP_RC_GeneralError;
+		ptpip_perror("write init cmd request");
+		if (ptpip_get_socket_error() == ETIMEDOUT)
+			return PTP_ERROR_TIMEOUT;
+		return PTP_ERROR_IO;
 	}
-	GP_LOG_E ("return %d / len %d", ret, len);
+	GP_LOG_D ("return %d / len %d", ret, len);
 	if (ret != len) {
 		GP_LOG_E ("return %d vs len %d", ret, len);
 		return PTP_RC_GeneralError;
@@ -724,9 +728,9 @@ ptp_fujiptpip_init_event (PTPParams* params, const char *address)
 	saddr.sin_family	= AF_INET;
 	saddr.sin_port		= htons(eventport);
 	do {
-		if (PTPSOCK_ERR != connect (params->evtfd, (struct sockaddr*)&saddr, sizeof(struct sockaddr_in)))
+		if (PTPSOCK_ERR != ptpip_connect_with_timeout (params->evtfd, (struct sockaddr*)&saddr, sizeof(struct sockaddr_in), PTPIP_DEFAULT_TIMEOUT_S, PTPIP_DEFAULT_TIMEOUT_MS))
 			break;
-		if ((errno == ECONNREFUSED) && (tries--)) {
+		if ((ptpip_get_socket_error() == ECONNREFUSED) && (tries--)) {
 			GP_LOG_D ("event connect failed, retrying after short wait");
 			int sleep_ms = 100;
 #ifdef WIN32
@@ -745,9 +749,9 @@ ptp_fujiptpip_init_event (PTPParams* params, const char *address)
 	saddr.sin_family	= AF_INET;
 	saddr.sin_port		= htons(eventport+1);
 	do {
-		if (PTPSOCK_ERR != connect (params->jpgfd, (struct sockaddr*)&saddr, sizeof(struct sockaddr_in)))
+		if (PTPSOCK_ERR != ptpip_connect_with_timeout (params->jpgfd, (struct sockaddr*)&saddr, sizeof(struct sockaddr_in), PTPIP_DEFAULT_TIMEOUT_S, PTPIP_DEFAULT_TIMEOUT_MS))
 			break;
-		if ((errno == ECONNREFUSED) && (tries--)) {
+		if ((ptpip_get_socket_error() == ECONNREFUSED) && (tries--)) {
 			GP_LOG_D ("jpeg connect failed, retrying after short wait");
 			int sleep_ms = 100;
 #ifdef WIN32
@@ -757,7 +761,7 @@ ptp_fujiptpip_init_event (PTPParams* params, const char *address)
 #endif
 			continue;
 		}
-		GP_LOG_E ("could not connect event");
+		GP_LOG_E ("could not connect jpeg");
 		PTPSOCK_CLOSE (params->jpgfd);
 		return GP_ERROR_IO;
 	} while (1);
@@ -799,7 +803,7 @@ ptp_fujiptpip_event (PTPParams* params, PTPContainer* event, int wait)
 		ret = select (params->evtfd+1, &infds, NULL, NULL, &timeout);
 		if (1 != ret) {
 			if (-1 == ret) {
-				GP_LOG_D ("select returned error, errno is %d", errno);
+				GP_LOG_D ("select returned error, errno is %d", ptpip_get_socket_error());
 				return PTP_ERROR_IO;
 			}
 			return PTP_ERROR_TIMEOUT;
@@ -863,7 +867,7 @@ ptp_fujiptpip_jpeg (PTPParams* params, unsigned char** xdata, unsigned int *xsiz
 		ret = select (params->jpgfd+1, &infds, NULL, NULL, &timeout);
 		if (1 != ret) {
 			if (-1 == ret) {
-				GP_LOG_D ("select returned error, errno is %d", errno);
+				GP_LOG_D ("select returned error, errno is %d", ptpip_get_socket_error());
 				return PTP_ERROR_IO;
 			}
 			return PTP_ERROR_TIMEOUT;
@@ -884,7 +888,7 @@ ptp_fujiptpip_jpeg (PTPParams* params, unsigned char** xdata, unsigned int *xsiz
 int
 ptp_fujiptpip_connect (PTPParams* params, const char *address) {
 	char 		*addr, *s, *p;
-	int		port, eventport;
+	int		port, eventport, connect_tries;
 	struct sockaddr_in	saddr;
 	uint16_t	ret;
 
@@ -938,40 +942,73 @@ ptp_fujiptpip_connect (PTPParams* params, const char *address) {
 	free (addr);
 	PTPSOCK_SOCKTYPE cmdfd = params->cmdfd = socket (PF_INET, SOCK_STREAM, PTPSOCK_PROTO);
 	if (cmdfd == PTPSOCK_INVALID) {
-		perror ("socket cmd");
+		ptpip_perror ("socket cmd");
 		return GP_ERROR_BAD_PARAMETERS;
 	}
+	if (ptpip_set_nonblock(cmdfd) == -1) {
+		ptpip_perror("cmdfd set nonblocking");
+		PTPSOCK_CLOSE (params->cmdfd);
+		return GP_ERROR_IO;
+	}
 	PTPSOCK_SOCKTYPE evtfd = params->evtfd = socket (PF_INET, SOCK_STREAM, PTPSOCK_PROTO);
 	if (evtfd == PTPSOCK_INVALID) {
-		perror ("socket evt");
+		ptpip_perror ("socket evt");
 		PTPSOCK_CLOSE (params->cmdfd);
 		return GP_ERROR_BAD_PARAMETERS;
 	}
-	PTPSOCK_SOCKTYPE jpgfd = params->jpgfd = socket (PF_INET, SOCK_STREAM, 0);
-	if (jpgfd == PTPSOCK_INVALID) {
-		perror ("socket jpg");
-		PTPSOCK_CLOSE (params->evtfd);
-		PTPSOCK_CLOSE (params->cmdfd);
-		return GP_ERROR_BAD_PARAMETERS;
-	}
-	if (PTPSOCK_ERR == connect (params->cmdfd, (struct sockaddr*)&saddr, sizeof(struct sockaddr_in))) {
-		perror ("connect cmd");
+	if (ptpip_set_nonblock(evtfd) == -1) {
+		ptpip_perror("evtfd set nonblocking");
 		PTPSOCK_CLOSE (params->cmdfd);
 		PTPSOCK_CLOSE (params->evtfd);
 		return GP_ERROR_IO;
 	}
-	ret = ptp_fujiptpip_init_command_request (params);
-	if (ret != PTP_RC_OK) {
+	PTPSOCK_SOCKTYPE jpgfd = params->jpgfd = socket (PF_INET, SOCK_STREAM, 0);
+	if (jpgfd == PTPSOCK_INVALID) {
+		ptpip_perror ("socket jpg");
+		PTPSOCK_CLOSE (params->evtfd);
+		PTPSOCK_CLOSE (params->cmdfd);
+		return GP_ERROR_BAD_PARAMETERS;
+	}
+	if (ptpip_set_nonblock(jpgfd) == -1) {
+		ptpip_perror("jpgfd set nonblocking");
 		PTPSOCK_CLOSE (params->cmdfd);
 		PTPSOCK_CLOSE (params->evtfd);
-		return translate_ptp_result (ret);
+		PTPSOCK_CLOSE (params->jpgfd);
+		return GP_ERROR_IO;
 	}
-	ret = ptp_fujiptpip_init_command_ack (params);
-	if (ret != PTP_RC_OK) {
+	if (PTPSOCK_ERR == ptpip_connect_with_timeout (params->cmdfd, (struct sockaddr*)&saddr, sizeof(struct sockaddr_in), PTPIP_DEFAULT_TIMEOUT_S, PTPIP_DEFAULT_TIMEOUT_MS)) {
+		ptpip_perror ("connect cmd");
 		PTPSOCK_CLOSE (params->cmdfd);
 		PTPSOCK_CLOSE (params->evtfd);
-		return translate_ptp_result (ret);
+		PTPSOCK_CLOSE (params->jpgfd);
+		return GP_ERROR_IO;
 	}
+	connect_tries = 0;
+	do {
+		ret = ptp_fujiptpip_init_command_request (params);
+		if (ret != PTP_RC_OK) {
+			PTPSOCK_CLOSE (params->cmdfd);
+			PTPSOCK_CLOSE (params->evtfd);
+			PTPSOCK_CLOSE (params->jpgfd);
+			return translate_ptp_result (ret);
+		}
+		connect_tries++;
+		ret = ptp_fujiptpip_init_command_ack (params);
+		if (ret == PTP_RC_AccessDenied && connect_tries < 2) {
+#ifdef WIN32
+			Sleep(500);
+#else
+			usleep(500*1000);
+#endif
+			continue;
+		}
+		if (ret != PTP_RC_OK) {
+			PTPSOCK_CLOSE (params->cmdfd);
+			PTPSOCK_CLOSE (params->evtfd);
+			PTPSOCK_CLOSE (params->jpgfd);
+			return translate_ptp_result (ret);
+		}
+	} while(connect_tries < 2);
 	GP_LOG_D ("fujiptpip connected!");
 	return GP_OK;
 }
