@@ -18,9 +18,14 @@
  * Boston, MA  02110-1301  USA
  */
 
+#ifndef CAMLIBS_PTP2_PTP_PRIVATE_H
+#define CAMLIBS_PTP2_PTP_PRIVATE_H
+
 /* ptp2 camlib private functions */
 #include <gphoto2/gphoto2-library.h>
 
+#include <string.h>
+
 /* config.c */
 int camera_get_config (Camera *camera, CameraWidget **window, GPContext *context);
 int camera_get_config_list (Camera *camera, CameraList *list, GPContext *context);
@@ -32,10 +37,11 @@ int camera_prepare_capture (Camera *camera, GPContext *context);
 int camera_unprepare_capture (Camera *camera, GPContext *context);
 int camera_canon_eos_update_capture_target(Camera *camera, GPContext *context, int value);
 int have_prop(Camera *camera, uint16_t vendor, uint16_t prop);
-
+int camera_lookup_by_property(Camera *camera, PTPDevicePropDesc *dpd, char **name, char **content, GPContext *context);
 
 /* library.c */
 int translate_ptp_result (uint16_t result);
+uint16_t translate_gp_result_to_ptp (int gp_result);
 int fixup_cached_deviceinfo (Camera *camera, PTPDeviceInfo*);
 
 int chdk_init(Camera*,GPContext*);
@@ -81,7 +87,7 @@ inline static int log_on_ptp_error_helper( int _r, const char* _func, const char
 	if (c_ptp_rep_ret != PTP_RC_OK) {\
 		const char* ptp_err_str = ptp_strerror(c_ptp_rep_ret, params->deviceinfo.VendorExtensionID);\
 		GP_LOG_E ("'%s' failed: '%s' (0x%04x)", #RESULT, ptp_err_str, c_ptp_rep_ret);\
-		gp_context_error (context, "%s", dgettext(GETTEXT_PACKAGE, ptp_err_str));\
+		gp_context_error (context, "%s", dgettext(GETTEXT_PACKAGE_LIBGPHOTO2, ptp_err_str));\
 		return translate_ptp_result (c_ptp_rep_ret);\
 	}\
 } while(0)
@@ -94,7 +100,7 @@ inline static int log_on_ptp_error_helper( int _r, const char* _func, const char
 		snprintf(fmt_str, sizeof(fmt_str), "%s%s%s", "'%s' failed: ", MSG, " (0x%04x: %s)");\
 		GP_LOG_E (fmt_str, #RESULT, ##__VA_ARGS__, c_ptp_rep_msg_ret, ptp_err_str);\
 		snprintf(fmt_str, sizeof(fmt_str), "%s%s", MSG, " (0x%04x: %s)");\
-		gp_context_error (context, fmt_str, ##__VA_ARGS__, c_ptp_rep_msg_ret, dgettext(GETTEXT_PACKAGE, ptp_err_str));\
+		gp_context_error (context, fmt_str, ##__VA_ARGS__, c_ptp_rep_msg_ret, dgettext(GETTEXT_PACKAGE_LIBGPHOTO2, ptp_err_str));\
 		return translate_ptp_result (c_ptp_rep_msg_ret);\
 	}\
 } while(0)
@@ -107,6 +113,47 @@ inline static int log_on_ptp_error_helper( int _r, const char* _func, const char
 	}\
 } while (0)
 
+static inline int
+is_canon_eos_m(PTPParams *params) {
+	if (params->deviceinfo.VendorExtensionID != PTP_VENDOR_CANON) return 0;
+	if (!ptp_operation_issupported(params, PTP_OC_CANON_EOS_SetRemoteMode)) return 0;
+	if (!params->deviceinfo.Model) return 0;
+
+	/* classic EOS M */
+	if (!strncmp(params->deviceinfo.Model, "Canon EOS M", strlen("Canon EOS M")))
+		return 1;
+
+	/* We encountered newer Powershot SX models that seem to have EOS M like firmware, see https://github.com/gphoto/libgphoto2/issues/316 */
+	if (	!strncmp(params->deviceinfo.Model, "Canon PowerShot SX", strlen("Canon PowerShot SX"))	||
+		!strncmp(params->deviceinfo.Model, "Canon PowerShot G",  strlen("Canon PowerShot G"))	||
+		!strncmp(params->deviceinfo.Model, "Canon Digital IXUS", strlen("Canon Digital IXUS"))
+	)
+		return ptp_operation_issupported(params, PTP_OC_CANON_EOS_RemoteReleaseOn);
+	return 0;
+}
+
+static inline int
+have_eos_prop(PTPParams *params, uint16_t vendor, uint16_t prop) {
+	unsigned int i;
+
+	/* The special Canon EOS property set gets special treatment. */
+	if ((params->deviceinfo.VendorExtensionID != PTP_VENDOR_CANON) || (vendor != PTP_VENDOR_CANON))
+		return 0;
+	for (i=0;i<params->nrofcanon_props;i++)
+		if (params->canon_props[i].proptype == prop)
+			return 1;
+	return 0;
+}
+
+static inline int
+have_sigma_prop(PTPParams *params, uint16_t vendor, uint16_t prop) {
+	/* The special Canon EOS property set gets special treatment. */
+	if ((params->deviceinfo.VendorExtensionID != PTP_VENDOR_GP_SIGMAFP) || (vendor != PTP_VENDOR_GP_SIGMAFP))
+		return 0;
+	if ((prop & 0xf000) == 0xd000)	/* we map it to vendor config space */
+		return 1;
+	return 0;
+}
 
 struct _CameraPrivateLibrary {
 	PTPParams params;
@@ -118,3 +165,5 @@ struct _PTPData {
 	GPContext *context;
 };
 typedef struct _PTPData PTPData;
+
+#endif /* !defined(CAMLIBS_PTP2_PTP_PRIVATE_H) */
