@@ -20,7 +20,7 @@
 #include "config.h"
 
 #include <stdlib.h>
-#include <_stdint.h>
+#include <stdint.h>
 #include <stdio.h>
 #include <string.h>
 
@@ -29,31 +29,16 @@
 #include <gphoto2/gphoto2-library.h>
 #include <gphoto2/gphoto2-port-log.h>
 
+#include "libgphoto2/i18n.h"
+
 #include "sierra.h"
 #include "sierra-desc.h"
 #include "library.h"
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (GETTEXT_PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define textdomain(String) (String)
-#  define gettext(String) (String)
-#  define dgettext(Domain,Message) (Message)
-#  define dcgettext(Domain,Message,Type) (Message)
-#  define bindtextdomain(Domain,Directory) (Domain)
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
 
 #define GP_MODULE "sierra"
 
+
 /*
  * For some reason, round() does not get a prototype from math.h.
  */
