@@ -1,6 +1,6 @@
 /* Sony DSC-F55 & MSAC-SR1 - gPhoto2 camera library
- * Copyright  2001, 2002, 2004 Raymond Penners <raymond@dotsphinx.com>
- * Copyright  2000 Mark Davies <mdavies@dial.pipex.com>
+ * Copyright 2001, 2002, 2004 Raymond Penners <raymond@dotsphinx.com>
+ * Copyright 2000 Mark Davies <mdavies@dial.pipex.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -14,11 +14,11 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  */
 
-#define _BSD_SOURCE
+#define _DEFAULT_SOURCE
 
 #include "config.h"
 
@@ -97,7 +97,7 @@ static unsigned char X13Camera[] = { 0, 2, 18 };
 
 
 /*
- * This array contains the expected packet sequence code to to be applied/
+ * This array contains the expected packet sequence code to be applied/
  * checked for.
  */
 static const unsigned char sony_sequence[] =
@@ -157,7 +157,7 @@ sony_baud_to_id(long baud)
 static int
 sony_read_byte(Camera * camera, unsigned char *b)
 {
-	int n = gp_port_read(camera->port, b, 1);
+	int n = gp_port_read(camera->port, (char *)b, 1);
 	if (n != 1)
 		return GP_ERROR;
 	else
@@ -316,7 +316,7 @@ sony_packet_write(Camera * camera, Packet * p)
 	 **/
 	usleep(10000);
 
-	rc = gp_port_write(camera->port, &START_PACKET, 1);
+	rc = gp_port_write(camera->port, (char *)&START_PACKET, 1);
 
 	p->buffer[p->length] = p->checksum;
 
@@ -478,7 +478,7 @@ sony_baud_set(Camera * camera, long baud)
 	if (camera->pl->current_baud_rate != baud) {
 		/* FIXME */
 		SetTransferRate[3] = sony_baud_to_id(baud);
-	
+
 		rc = sony_converse(camera, &dp, SetTransferRate, 4);
 		if (rc == GP_OK) {
 			sony_baud_port_set(camera, baud);
@@ -497,7 +497,7 @@ sony_baud_set(Camera * camera, long baud)
 }
 
 /**
- * Port initialisation
+ * Port initialization
  */
 static int
 sony_init_port (Camera *camera)
@@ -559,7 +559,7 @@ sony_is_mpeg_supported (Camera * camera)
 }
 
 /**
- * Initialises camera
+ * Initialize camera
  */
 int
 sony_init (Camera * camera, SonyModel model)
@@ -700,7 +700,7 @@ sony_file_get(Camera * camera, int imageid, int file_type,
 	int sc;			/* count of bytes to skip at start of packet */
 	Packet dp;
 	int rc;
-	char buffer[128];                                                 
+	char buffer[128];
 
 	GP_DEBUG( "sony_file_get()");
 
@@ -708,7 +708,7 @@ sony_file_get(Camera * camera, int imageid, int file_type,
 	if (rc != GP_OK) {
 		return rc;
 	}
-	
+
 	if (gp_context_cancel(context) == GP_CONTEXT_FEEDBACK_CANCEL) {
 		return GP_ERROR_CANCEL;
 	}
@@ -862,7 +862,7 @@ sony_image_info(Camera * camera, int imageid, SonyFileType file_type,
 	if (rc != GP_OK) {
 		return rc;
 	}
-	
+
 	if (gp_context_cancel(context) == GP_CONTEXT_FEEDBACK_CANCEL) {
 		return GP_ERROR_CANCEL;
 	}
