@@ -36,7 +36,7 @@
 #include <gphoto2/gphoto2.h>
 #include <gphoto2/gphoto2-port.h>
 #include <gphoto2/gphoto2-port-log.h>
-#include "gphoto2-endian.h"
+#include "libgphoto2/gphoto2-endian.h"
 
 #define GP_MODULE "spca50x"
 #include "spca50x.h"
@@ -149,13 +149,13 @@ spca50x_flash_get_TOC(CameraPrivateLibrary *pl, int *filecount)
 						(char*)&n_toc_entries, 0x02));
 			/* Each file gets two toc entries, one for the image,
 			   one for the thumbnail */
-			LE16TOH (n_toc_entries);
+			le16toh (n_toc_entries);
 			*filecount = n_toc_entries/2;
 		} else {
 			CHECK (gp_port_usb_msg_read (pl->gpdev,
 						0x54, 0x0000, 0x0000,
 						(char*)&n_toc_entries, 0x02));
-			LE16TOH (n_toc_entries);
+			le16toh (n_toc_entries);
 			*filecount = n_toc_entries;
 		}
 		/* If empty, return now */
@@ -225,13 +225,13 @@ spca50x_flash_get_filecount (CameraPrivateLibrary *pl, int *filecount)
 						(char*)&response, 0x02));
 			/* Each file gets two toc entries, one for the
 			   image, one for the thumbnail */
-			LE16TOH (response);
+			le16toh (response);
 			*filecount = response/2;
 		} else {
 			CHECK (gp_port_usb_msg_read (pl->gpdev,
 						0x54, 0x0000, 0x0000,
 						(char*)&response, 0x02));
-			LE16TOH (response);
+			le16toh (response);
 			*filecount = response;
 		}
 	}
