@@ -33,21 +33,11 @@
 #include <gphoto2/gphoto2-result.h>
 #include <gphoto2/gphoto2-port.h>
 #include <gphoto2/gphoto2-setting.h>
+
+#include "libgphoto2/i18n.h"
+
 #include "st2205.h"
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (GETTEXT_PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
 
 int
 camera_id (CameraText *id)
