@@ -13,20 +13,23 @@
  * GNU Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  */
-#ifndef __ST2205_H__
-#define __ST2205_H__
+
+#ifndef CAMLIBS_ST2205_ST2205_H
+#define CAMLIBS_ST2205_ST2205_H
+
 #include "config.h"
 
 #include <stdio.h>
-#ifdef HAVE_ICONV
+#if defined(HAVE_ICONV) && defined(HAVE_LANGINFO_H)
 #include <iconv.h>
 #endif
 
 #include <gphoto2/gphoto2-library.h>
-#include <gphoto2-endian.h>
+#include <libgphoto2/gphoto2-endian.h>
 
 #define GP_MODULE "st2205"
 
@@ -93,7 +96,7 @@ typedef int16_t st2205_lookup_row[8];
 
 struct _CameraPrivateLibrary {
 	/* Used by library.c glue code */
-#ifdef HAVE_ICONV
+#if defined(HAVE_ICONV) && defined(HAVE_LANGINFO_H)
 	iconv_t	cd;
 #endif
 	st2205_filename filenames[ST2205_MAX_NO_FILES];
@@ -115,13 +118,16 @@ struct _CameraPrivateLibrary {
 	int no_fats;
 	int block_is_present[2097152 / ST2205_BLOCK_SIZE];
 	int block_dirty[2097152 / ST2205_BLOCK_SIZE];
-	st2205_lookup_row lookup[3][256];
 	struct st2205_coord shuffle[8][ST2205_SHUFFLE_SIZE];
 	int no_shuffles;
 	unsigned char unknown3[8];
 	unsigned int rand_seed;
 };
 
+/* tables in st2205_tables.c */
+extern const st2205_lookup_row st2205_lookup[3][256];
+extern const uint8_t st2205_shuffle_data[10360];
+
 /* functions in st2205.c */
 int
 st2205_open_device(Camera *camera);
@@ -180,4 +186,4 @@ int
 st2205_rgb24_to_rgb565(CameraPrivateLibrary *pl, int **src,
 	unsigned char *dest);
 
-#endif
+#endif /* !defined(CAMLIBS_ST2205_ST2205_H) */
