@@ -27,27 +27,16 @@
 #include <gphoto2/gphoto2.h>
 #include <gphoto2/gphoto2-port.h>
 
+#include "libgphoto2/i18n.h"
+
 #include "stv0680.h"
 #include "library.h"
 #include "sharpen.h"
-#include "bayer.h"
+#include "stv0680-bayer.h"
 #include "saturate.h"
-#include "../../libgphoto2/bayer.h"
+#include "libgphoto2/bayer.h"
 #include "demosaic_sharpen.h"
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (GETTEXT_PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
 
 #define CMD_RETRIES		0x03
 
