@@ -25,7 +25,7 @@
 #include <stdlib.h>
 
 #include <gphoto2/gphoto2.h>
-#include "gphoto2-endian.h"
+#include "libgphoto2/gphoto2-endian.h"
 
 #define	GP_MODULE	"pdrm11"
 #define	ETIMEDOUT	110
