@@ -46,7 +46,7 @@
 #include <time.h>
 
 #include "config.h"
-#include "bayer.h"
+#include "libgphoto2/bayer.h"
 #include <gphoto2/gphoto2-result.h>
 #include <gphoto2/gphoto2-port-log.h>
 
