@@ -37,25 +37,10 @@
 #include <gphoto2/gphoto2-result.h>
 #include <gphoto2/gphoto2-library.h>
 #include <gphoto2/gphoto2-port-log.h>
+#include <gphoto2/gphoto2-port-locking.h>
+
+#include "libgphoto2/i18n.h"
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (GETTEXT_PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define textdomain(String) (String)
-#  define gettext(String) (String)
-#  define dgettext(Domain,Message) (Message)
-#  define dcgettext(Domain,Message,Type) (Message)
-#  define bindtextdomain(Domain,Directory) (Domain)
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
 
 #define CAMERA_UNUSED(c,ctx)						\
 {									\
@@ -263,6 +248,7 @@ struct _CameraPrivateCore {
 int
 gp_camera_exit (Camera *camera, GPContext *context)
 {
+	int exit_result = GP_OK;
 	C_PARAMS (camera);
 
 	GP_LOG_D ("Exiting camera ('%s')...", camera->pc->a.model);
@@ -287,22 +273,24 @@ gp_camera_exit (Camera *camera, GPContext *context)
 #ifdef HAVE_MULTI
 		gp_port_open (camera->port);
 #endif
-		camera->functions->exit (camera, context);
+		exit_result = camera->functions->exit (camera, context);
 	}
 	gp_port_close (camera->port);
 	memset (camera->functions, 0, sizeof (CameraFunctions));
 
 	if (camera->pc->lh) {
 #if !defined(VALGRIND)
+		gpi_libltdl_lock();
 		lt_dlclose (camera->pc->lh);
 		lt_dlexit ();
+		gpi_libltdl_unlock();
 #endif
 		camera->pc->lh = NULL;
 	}
 
 	gp_filesystem_reset (camera->fs);
 
-	return (GP_OK);
+	return exit_result;
 }
 
 
@@ -792,21 +780,29 @@ gp_camera_init (Camera *camera, GPContext *context)
 
 	/* Load the library. */
 	GP_LOG_D ("Loading '%s'...", camera->pc->a.library);
+	gpi_libltdl_lock();
 	lt_dlinit ();
 	camera->pc->lh = lt_dlopenext (camera->pc->a.library);
+	gpi_libltdl_unlock();
 	if (!camera->pc->lh) {
+		gpi_libltdl_lock();
 		gp_context_error (context, _("Could not load required "
 			"camera driver '%s' (%s)."), camera->pc->a.library,
 			lt_dlerror ());
 		lt_dlexit ();
+		gpi_libltdl_unlock();
 		return (GP_ERROR_LIBRARY);
 	}
 
 	/* Initialize the camera */
+	gpi_libltdl_lock();
 	init_func = lt_dlsym (camera->pc->lh, "camera_init");
+	gpi_libltdl_unlock();
 	if (!init_func) {
+		gpi_libltdl_lock();
 		lt_dlclose (camera->pc->lh);
 		lt_dlexit ();
+		gpi_libltdl_unlock();
 		camera->pc->lh = NULL;
 		gp_context_error (context, _("Camera driver '%s' is "
 			"missing the 'camera_init' function."),
@@ -817,8 +813,10 @@ gp_camera_init (Camera *camera, GPContext *context)
 	if (strcasecmp (camera->pc->a.model, "Directory Browse")) {
 		result = gp_port_open (camera->port);
 		if (result < 0) {
+			gpi_libltdl_lock();
 			lt_dlclose (camera->pc->lh);
 			lt_dlexit ();
+			gpi_libltdl_unlock();
 			camera->pc->lh = NULL;
 			return (result);
 		}
@@ -827,8 +825,10 @@ gp_camera_init (Camera *camera, GPContext *context)
 	result = init_func (camera, context);
 	if (result < 0) {
 		gp_port_close (camera->port);
+		gpi_libltdl_lock();
 		lt_dlclose (camera->pc->lh);
 		lt_dlexit ();
+		gpi_libltdl_unlock();
 		camera->pc->lh = NULL;
 		memset (camera->functions, 0, sizeof (CameraFunctions));
 		return (result);
