@@ -37,6 +37,7 @@
 #include <gphoto2/gphoto2-port-result.h>
 #include <gphoto2/gphoto2-port-library.h>
 #include <gphoto2/gphoto2-port-log.h>
+#include <gphoto2/gphoto2-port-locking.h>
 
 #include "libgphoto2_port/gphoto2-port-info.h"
 
@@ -159,26 +160,36 @@ gp_port_set_info (GPPort *port, GPPortInfo info)
 	}
 	if (port->pc->lh) {
 #if !defined(VALGRIND)
+		gpi_libltdl_lock();
 		lt_dlclose (port->pc->lh);
 		lt_dlexit ();
+		gpi_libltdl_unlock();
 #endif
 	}
 
+	gpi_libltdl_lock();
 	lt_dlinit ();
 	port->pc->lh = lt_dlopenext (info->library_filename);
+	gpi_libltdl_unlock();
 	if (!port->pc->lh) {
+		gpi_libltdl_lock();
 		GP_LOG_E ("Could not load '%s' ('%s').", info->library_filename, lt_dlerror ());
 		lt_dlexit ();
+		gpi_libltdl_unlock();
 		return (GP_ERROR_LIBRARY);
 	}
 
 	/* Load the operations */
+	gpi_libltdl_lock();
 	ops_func = lt_dlsym (port->pc->lh, "gp_port_library_operations");
+	gpi_libltdl_unlock();
 	if (!ops_func) {
+		gpi_libltdl_lock();
 		GP_LOG_E ("Could not find 'gp_port_library_operations' in '%s' ('%s')",
 			  info->library_filename, lt_dlerror ());
 		lt_dlclose (port->pc->lh);
 		lt_dlexit ();
+		gpi_libltdl_unlock();
 		port->pc->lh = NULL;
 		return (GP_ERROR_LIBRARY);
 	}
@@ -344,8 +355,10 @@ gp_port_free (GPPort *port)
 
 		if (port->pc->lh) {
 #if !defined(VALGRIND)
+			gpi_libltdl_lock();
 			lt_dlclose (port->pc->lh);
 			lt_dlexit ();
+			gpi_libltdl_unlock();
 #endif
 			port->pc->lh = NULL;
 		}
